@@ -90,7 +90,7 @@ use warnings;
 
 use base qw{Exporter};
 
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @EXPORT_OK = qw{shell BODY_STATUS_IS_OPERATIONAL BODY_STATUS_IS_SPARE
     BODY_STATUS_IS_TUMBLING};
 our %EXPORT_TAGS = (
@@ -466,13 +466,45 @@ end; for example, the name of the 'International Space Station' data set
 is 'stations', since the URL for this is
 L<http://celestrak.com/NORAD/elements/stations.txt>.
 
-As of October 11 2007, the data set for the debris from the People's
-Republic of China's anti-satellite test against their Fengyun 1C
-satellite is available from Celestrak only by direct-fetching ($st->set
-(direct => 1), see below), as data set '1999-025'. I have not
-corresponded with Dr. Kelso on this, but I think it reasonable to
-believe that the effect of asking Space Track for all 2126 pieces of
-debris at once would not be good.
+The Celestrak web site makes a few items available for direct-fetching
+only (C<$st->set(direct => 1)>, see below.) These are typically debris
+from collisions or explosions. I have not corresponded with Dr. Kelso on
+this, but I think it reasonable to believe that asking Space Track for a
+couple thousand sets of data at once would not be a good thing.
+
+As of this release, the following data sets may be direct-fetched only:
+
+=over
+
+=item 1999-025
+
+This is the debris of Chinese communication satellite Fengyun 1C,
+created by an antisatellite test on January 11 2007. As of March 9
+2009 there are 2375 pieces of debris in the data set.
+
+=item usa-193-debris
+
+This is the debris of U.S. spy satellite USA-193 shot down by the U.S.
+on February 20 2008. As of March 9 2009 there is only 1 piece of
+debris in the data set, down from a maximum of 173. I presume that when
+this decays, a direct fetch of 'usa-193-debris' will return 404, but
+your guess is as good as mine.
+
+=item cosmos-2251-debris
+
+This is the debris of Russian communication satellite Cosmos 2251,
+created by its collision with Iridium 33 on February 10 2009. As of
+March 9 there are 357 pieces of debris in the data set, but
+more are expected.
+
+=item iridium-33-debris
+
+This is the debris of U.S. communication satellite Iridium 33, created
+by its collision with Cosmos 2251 on February 10 2009. As of March 9
+2009 there are 159 pieces of debris in the data set, but more are
+expected.
+
+=back
 
 The data set for the current US Space Shuttle Mission (if any) will be
 available as data set 'sts'. If there is no current mission, you will
@@ -563,7 +595,7 @@ sub _celestrak_direct {
 		$1 == RC_NOT_FOUND
 		    and return $self->_no_such_catalog(
 		    celestrak => $name, $msg);
-		return HTTP::Response->new ($1, "$msg\n")
+		return HTTP::Response->new (+$1, "$msg\n")
 	    }
 	}
 	my $type = lc $resp->header('Content-Type')
@@ -2394,7 +2426,7 @@ sub _parse_retrieve_dates {
 	next unless $opt->{$key};
 	$opt->{$key} !~ m/\D/ or
 	    $opt->{$key} =~ m/^(\d+)\D+(\d+)\D+(\d+)$/ and
-		$opt->{$key} = eval {timegm (0, 0, 0, $3, $2-1, $1)} or
+		$opt->{$key} = eval {timegm (0, 0, 0, +$3, $2-1, +$1)} or
 	    croak <<eod;
 Error - Illegal date '$opt->{$key}'. Valid dates are a number
 	(interpreted as a Perl date) or numeric year-month-day.
